#
# spec file for package python3-Pygments
#
# Copyright (c) 2015 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python3-Pygments
Version:        2.0.2
Release:        6.2
Url:            http://pygments.org
Summary:        Pygments is a syntax highlighting package written in Python
License:        BSD-2-Clause
Group:          Development/Languages/Python
Source:         http://pypi.python.org/packages/source/P/Pygments/Pygments-%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  python3-devel
BuildRequires:  python3-nose
BuildRequires:  python3-setuptools
Requires:       python3-setuptools
BuildArch:      noarch

%description
Pygments is a syntax highlighting package written in Python.

It is a generic syntax highlighter for general use in all kinds of software
such as forum systems, wikis or other applications that need to prettify
source code. Highlights are:

 * a wide range of common languages and markup formats is supported
 * special attention is paid to details, increasing quality by a fair amount
 * support for new languages and formats are added easily
 * a number of output formats, presently HTML, LaTeX, RTF, SVG, all image
   formats that PIL supports and ANSI sequences
 * it is usable as a command-line tool and as a library
 * ... and it highlights even Brainfuck!

%prep
%setup -q -n Pygments-%{version}
# Remove non-oss licensed files, see bnc# 760344
rm tests/examplefiles/{Sorting,test}.mod
sed -i "s|pygmentize|pygmentize-%{py3_ver}|" setup.py # Add Python3 version suffix

%build
python3 setup.py build

%install
python3 setup.py install --prefix=%{_prefix} --root=%{buildroot}
# Rename man-page to avoid conflicts with the python 2 version
install -Dm0644 doc/pygmentize.1 %{buildroot}%{_mandir}/man1/pygmentize-%{py3_ver}.1

%files
%defattr(-,root,root,-)
%doc LICENSE AUTHORS CHANGES TODO
%{_bindir}/pygmentize-%{py3_ver}
%{_mandir}/man1/pygmentize-%{py3_ver}.1.gz
%{python3_sitelib}/pygments/
%{python3_sitelib}/Pygments-%{version}-py%{py3_ver}.egg-info/

%changelog
* Sun Feb  8 2015 p.drouand@gmail.com
- Revert documentation building; avoid a build cycle with python3-Sphinx
- Remove python3 build requires; useless
* Sun Jan 25 2015 arun@gmx.de
- specfile:
  * add rules to make doc/build
  * add Sphings as requirement
  * remove 2to3 as requirement
- update to version 2.0.2:
  * Fix Python tracebacks getting duplicated in the console lexer (#1068).
  * Backquote-delimited identifiers are now recognized in F# (#1062).
* Thu Jan  1 2015 arun@gmx.de
- specfile:
  * changed coyright year
  * updated path to man-page in tar-ball (docs->doc)
  * updated path: docs/build -> doc/_build
* Thu Dec 18 2014 arun@gmx.de
- update to version 2.0.1:
  * Fix an encoding issue when using ``pygmentize`` with the ``-o`` option.
- changes from version 2.0:
  * Default lexer encoding is now "guess", i.e. UTF-8 / Locale /
    Latin1 is tried in that order.
  * Major update to Swift lexer (PR#410).
  * Multiple fixes to lexer guessing in conflicting cases
  * recognize HTML5 by doctype
  * recognize XML by XML declaration
  * don't recognize C/C++ as SystemVerilog
  * Simplified regexes and builtin lists.
- changes from version 2.0rc1:
  * Dropped Python 2.4 and 2.5 compatibility.  This is in favor of single-source
    compatibility between Python 2.6, 2.7 and 3.3+.
  * New website and documentation based on Sphinx (finally!)
  * Lexers added:
  * APL (#969)
  * Agda and Literate Agda (PR#203)
  * Alloy (PR#355)
  * AmbientTalk
  * BlitzBasic (PR#197)
  * ChaiScript (PR#24)
  * Chapel (PR#256)
  * Cirru (PR#275)
  * Clay (PR#184)
  * ColdFusion CFC (PR#283)
  * Cryptol and Literate Cryptol (PR#344)
  * Cypher (PR#257)
  * Docker config files
  * EBNF (PR#193)
  * Eiffel (PR#273)
  * GAP (PR#311)
  * Golo (PR#309)
  * Handlebars (PR#186)
  * Hy (PR#238)
  * Idris and Literate Idris (PR#210)
  * Igor Pro (PR#172)
  * Inform 6/7 (PR#281)
  * Intel objdump (PR#279)
  * Isabelle (PR#386)
  * Jasmin (PR#349)
  * JSON-LD (PR#289)
  * Kal (PR#233)
  * Lean (PR#399)
  * LSL (PR#296)
  * Limbo (PR#291)
  * Liquid (#977)
  * MQL (PR#285)
  * MaskJS (PR#280)
  * Mozilla preprocessors
  * Mathematica (PR#245)
  * NesC (PR#166)
  * Nit (PR#375)
  * Nix (PR#267)
  * Pan
  * Pawn (PR#211)
  * Perl 6 (PR#181)
  * Pig (PR#304)
  * Pike (PR#237)
  * QBasic (PR#182)
  * Red (PR#341)
  * ResourceBundle (#1038)
  * Rexx (PR#199)
  * Rql (PR#251)
  * Rsl
  * SPARQL (PR#78)
  * Slim (PR#366)
  * Swift (PR#371)
  * Swig (PR#168)
  * TADS 3 (PR#407)
  * Todo.txt todo lists
  * Twig (PR#404)
  * Added a helper to "optimize" regular expressions that match one of many
    literal words; this can save 20%% and more lexing time with lexers that
    highlight many keywords or builtins.
  * New styles: "xcode" and "igor", similar to the default highlighting of
    the respective IDEs.
  * The command-line "pygmentize" tool now tries a little harder to find the
    correct encoding for files and the terminal (#979).
  * Added "inencoding" option for lexers to override "encoding" analogous
    to "outencoding" (#800).
  * Added line-by-line "streaming" mode for pygmentize with the "-s" option.
    (PR#165)  Only fully works for lexers that have no constructs spanning
    lines!
  * Added an "envname" option to the LaTeX formatter to select a replacement
    verbatim environment (PR#235).
  * Updated the Makefile lexer to yield a little more useful highlighting.
  * Lexer aliases passed to ``get_lexer_by_name()`` are now case-insensitive.
  * File name matching in lexers and formatters will now use a regex cache
    for speed (PR#205).
  * Pygments will now recognize "vim" modelines when guessing the lexer for
    a file based on content (PR#118).
  * Major restructure of the ``pygments.lexers`` module namespace.  There are now
    many more modules with less lexers per module.  Old modules are still around
    and re-export the lexers they previously contained.
  * The NameHighlightFilter now works with any Name.* token type (#790).
  * Python 3 lexer: add new exceptions from PEP 3151.
  * Opa lexer: add new keywords (PR#170).
  * Julia lexer: add keywords and underscore-separated number
    literals (PR#176).
  * Lasso lexer: fix method highlighting, update builtins. Fix
    guessing so that plain XML isn't always taken as Lasso (PR#163).
  * Objective C/C++ lexers: allow "@" prefixing any expression (#871).
  * Ruby lexer: fix lexing of Name::Space tokens (#860) and of symbols
    in hashes (#873).
  * Stan lexer: update for version 2.4.0 of the language (PR#162, PR#255, PR#377).
  * JavaScript lexer: add the "yield" keyword (PR#196).
  * HTTP lexer: support for PATCH method (PR#190).
  * Koka lexer: update to newest language spec (PR#201).
  * Haxe lexer: rewrite and support for Haxe 3 (PR#174).
  * Prolog lexer: add different kinds of numeric literals (#864).
  * F# lexer: rewrite with newest spec for F# 3.0 (#842), fix a bug with
    dotted chains (#948).
  * Kotlin lexer: general update (PR#271).
  * Rebol lexer: fix comment detection and analyse_text (PR#261).
  * LLVM lexer: update keywords to v3.4 (PR#258).
  * PHP lexer: add new keywords and binary literals (PR#222).
  * external/markdown-processor.py updated to newest python-markdown (PR#221).
  * CSS lexer: some highlighting order fixes (PR#231).
  * Ceylon lexer: fix parsing of nested multiline comments (#915).
  * C family lexers: fix parsing of indented preprocessor directives (#944).
  * Rust lexer: update to 0.9 language version (PR#270, PR#388).
  * Elixir lexer: update to 0.15 language version (PR#392).
  * Fix swallowing incomplete tracebacks in Python console lexer (#874).
* Thu May  8 2014 toddrme2178@gmail.com
- add LICENSE to doc section
- Require python-setuptools instead of distribute (upstreams merged)
* Fri May  3 2013 toddrme2178@gmail.com
- Update to version 1.6:
  - Lexers added
  - Fix unquoted HTML attribute lexing in Opa .
  - The HTML formatter now supports linking to tags using CTags files, when the
    python-ctags package is installed .
  - The HTML formatter now has a "linespans" option that wraps every line in a
    <span> tag with a specific id .
  - When deriving a lexer from another lexer with token definitions, definitions
    for states not in the child lexer are now inherited.  If you override a state
    in the child lexer, an "inherit" keyword has been added to insert the base
    state at that position .
  - The C family lexers now inherit token definitions from a common base class,
    removing code duplication .
  - Use "colorama" on Windows for console color output .
  - Fix Template Haskell highlighting .
  - Fix some S/R lexer errors .
  - Fix a bug in the Prolog lexer with names that start with 'is' .
  - Rewrite Dylan lexer, add Dylan LID lexer .
  - Add a Java quickstart document .
  - Add a "external/autopygmentize" file that can be used as .lessfilter .
* Tue Nov 20 2012 saschpe@suse.de
- Name Python3 binaries consistently:
  + Fix in setup.py to have correct egg-info data
* Thu May  3 2012 toddrme2178@gmail.com
- Removed files with non-oss license, see bnc#760344
- Cleanups in python 2 and python 3 spec files
* Mon Apr 30 2012 toddrme2178@gmail.com
- Fix building python 3 package on openSUSE 11.4 x86_64
* Thu Dec 15 2011 highwaystar.ru@gmail.com
- initial build for python3
